WebTest wrapper
===============

The class ``FuncWebTestMixin`` has some WebTest specific methods/attributes, as well as the :doc:`common`.

.. currentmodule:: django_functest

.. class:: FuncWebTestMixin

   .. attribute:: last_response

      This is an object containing the last HTTP response, as documented in `the
      WebTest docs
      <http://webtest.pythonpaste.org/en/latest/testresponse.html>`_.
